/**************************************************************************/
/*  Klavaro - a flexible touch typing tutor                               */
/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
/*                                                                        */
/*  This program is free software, licensed under the terms of the GNU    */
/*  General Public License as published by the Free Software Foundation,  */
/*  which is also included in this package, in a file named "COPYING".    */
/**************************************************************************/

#define MAX_PARAGRAPHS 100
#define MAX_PAR_LEN 2001

/*
 * Interface functions
 */
gchar *fluid_get_paragraph_name (void);

void fluid_reset_paragraph (void);

gchar *get_par (gint index);

/*
 * Auxiliar functions
 */
void fluid_init (void);

void fluid_init_paragraph_list (gchar * list_name);

void fluid_draw_random_paragraphs (void);

gchar *fluid_filter_utf8 (gchar * text);

void fluid_text_write_to_file (gchar * text_raw);

void fluid_copy_text_file (gchar * file_name);

void fluid_comment (gdouble accuracy, gdouble velocity, gdouble fluidness);
